#region Namespaces
using System;
using System.Collections.Generic;
using System.Diagnostics;
using Autodesk.Revit.ApplicationServices;
using Autodesk.Revit.Attributes;
using Autodesk.Revit.DB;
using Autodesk.Revit.UI;
using Autodesk.Revit.UI.Selection;
#endregion

namespace RevitDevTV2015
{
  [Transaction(TransactionMode.Manual)]
  public class Command : IExternalCommand
  {
    public Result Execute(
      ExternalCommandData commandData,
      ref string message,
      ElementSet elements)
    {
      UIApplication uiapp = commandData.Application;
      UIDocument uidoc = uiapp.ActiveUIDocument;
      Application app = uiapp.Application;
      Document doc = uidoc.Document;

      // access the selection before the command begins
      Selection sel = uidoc.Selection;

      // iterate through the selection
      foreach (ElementId eleId in sel.GetElementIds())
      {
        // get the element by the id
        Element ele = doc.GetElement(eleId);
        // now we can show the category and name
        TaskDialog.Show(ele.Category.Name, ele.Name);
      }

      // let's get all the doors inside this project
      FilteredElementCollector collDoors = new FilteredElementCollector(doc);
      collDoors.OfCategory(BuiltInCategory.OST_Doors);
      collDoors.OfClass(typeof(FamilyInstance));

      // iterate through the collection
      foreach (Element ele in collDoors)
      {
        // will contain the information from the parameters
        System.Text.StringBuilder paramText = new System.Text.StringBuilder();

        foreach (Parameter param in ele.Parameters)
        {
          // first let's get the parameter name
          paramText.AppendFormat("{0}: ", param.Definition.Name);
          // get the information
          switch (param.StorageType)
          {
            case StorageType.String:
              paramText.Append(param.AsString());
              break;
            case StorageType.Double:
              paramText.AppendFormat("{0:0.00}", param.AsDouble());
              break;
          }
          // add a breakline
          paramText.AppendLine();
        }

        TaskDialog.Show(ele.Name, paramText.ToString());
      }


      return Result.Succeeded;
    }
  }
}
